use Acme::Python;
Hisssssssssssssssss
hiss Hiss hiss Hiss hisssssssss Hissss hisss 
Hiss hisss Hissss hiss Hiss hisss Hiss hiss 
Hisss hisss Hissss hiss Hisss hissss Hiss 
hiss Hissss hisssssss Hiss hissss Hiss hissss 
Hiss hisss Hiss hissss Hisss hissss Hissss 
hiss Hiss hissss Hissss hiss Hiss hisss Hiss 
hissss Hisss hisssssss Hisss hisssss Hissss 
hiss Hiss hisss Hissss hiss Hisss hisss Hiss 
hissss Hiss hisss Hisss hiss Hissss hissss 
Hiss hiss Hiss hisssssssss Hissss hisss Hiss 
hisss Hissss hiss Hiss hisss Hiss hiss Hisss 
hisss Hissss hiss Hisss hissss Hiss hiss 
Hissss hisssssss Hiss hissss Hiss hissss 
Hiss hisss Hisssss hiss Hisss hiss Hisss 
hiss Hiss hiss Hisss hisssssss Hiss hisssss 
Hiss hisss Hiss hisss Hissssss hiss Hiss 
hissss Hissss hiss Hiss hisss Hissss hiss 
Hisss hisss Hiss hissss Hiss hissssssss Hiss 
hissss Hisss hisss Hisss hiss Hisssss hiss 
Hisss hisss Hiss hisss Hissss hisssssss Hiss 
hisss Hiss hissss Hisss hissss Hissss hiss 
Hiss hissss Hissss hiss Hiss hisss Hiss hissss 
Hisss hisssssss Hisss hisss Hisss hiss Hissss 
hissss Hiss hiss Hiss hisssss